# Raumplaner.py

from grafikfenster import *

from tisch import Tisch
from stuhl import Stuhl
from tischgruppe import Tischgruppe
from schrankwand import Schrankwand
from sitzgruppe import Sitzgruppe
from moebelgruppe import Moebelgruppe

import pickle

### ---------------------------------------------------
class RaumplanerApp(wx.App):
    """Testanwendung fuer Raumplaner-Grafik
       ShellFrame: Interaktion mit laufender Anwendung
       FillingFrame: Anzeige der Umgebung"""
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        #self.fenster.ZeigeFillingFrame()
        ##Zeichenflaeche.GibZeichenflaeche().SetBGImage('beispielbild.png',0.8)
        ##Zeichenflaeche.GibZeichenflaeche().SetBGColor('BLACK')
        self.__alleMoebel=[]
        return True

    def GibAlle(self):
        return self.__alleMoebel

    def BildExport(self, dateiname="Bild.png"):
        '''Export des aktuellen Bilds'''
        print(Zeichenflaeche.GibZeichenflaeche().BildExport(dateiname))

    def Speichere(self, dateiname):
        """Objektdaten werden in Datei geschrieben"""
        try:
            with open(dateiname, 'wb') as objekt_datei:
                pickle.dump(self.__alleMoebel,
                            objekt_datei)
                return 'OK'
        except IOError as ioerr:
            return 'Dateifehler: ' + str(ioerr)
        except pickle.PicklingError as perr:
            return 'Pickle-Fehler: ' + str(perr)

    def Lade(self, dateiname):
        """Objektdaten werden aus der Datei gelesen"""
        ## Vorhandene Objekte aus Darstellung und Liste
        ## entfernen ! (fehlt hier)
        try:
            with open(dateiname, 'rb') as objekt_datei:
                self.__alleMoebel = pickle.load(objekt_datei)
                for moebel in self.__alleMoebel:
                    if moebel.GibSichtbar():
                        moebel.Zeige()
                return 'OK'
        except IOError:
             return 'Datei nicht auffindbar!'
        except AttributeError as ae:
            return 'AttributeError: ' + str(ae)
        except pickle.UnpicklingError as perr:
            return 'Pickle-Fehler: ' + str(perr)

    def TestAnwendungTischgruppe1(self):        
        global tg
        print('global: tg\ntg mit sechs Stühlen')
        try:
            tg.LoescheAlle()
        except Exception as e:
            tg=Tischgruppe(sichtbar=True)
        tg.SetzeStuehle()

    def TestAnwendungTischgruppe2(self):
        global tg
        print('global: tg\nAbmessungen 3x2, 10 Stühle')
        try:
            tg.LoescheAlle()
        except Exception as e:
            tg=Tischgruppe(sichtbar=True)
        tg.SetzeStuehle(3,2)
        
    def TestAnwendungSchrankwand1(self):
        global schrankwand
        print('global: schrankwand\nSchrankwand mit drei Schränken')
        schrankwand=Schrankwand(sichtbar=True)

    def TestAnwendungSchrankwand2(self):
        global schrankwand
        print('global: schrankwand\nSchrankwand mit fünf Schränken')
        schrankwand=Schrankwand(sichtbar=True)
        schrankwand.SetzeWerte(5)

    def TestAnwendungSitzgruppe(self):        
        global sitzgruppe
        print('global: sitzgruppe\nSitzgruppe mit zwei Sofas und zwei Sesseln')
        sitzgruppe=Sitzgruppe(sichtbar=True)

    def TestGruppeInGruppe(self):
        """verbindet zwei Gruppen zu einer neuen Gruppe
        vorher: app.TestAnwendungSchrankwand2()
        und: app.TestAnwendungSitzgruppe()"""
        global schrankwand, sitzgruppe, moebelgruppe
        if schrankwand==None: return
        if sitzgruppe==None: return
        moebelgruppe = Moebelgruppe(0, 0, sichtbar=True)
        moebelgruppe.FuegeHinzu(schrankwand)
        moebelgruppe.FuegeHinzu(sitzgruppe)
        schrankwand.BewegeVertikal(-150)
        print("Anschließen Gruppe testen mit:")
        print("moebelgruppe.BewegeHorizontal(-100)")
        print("moebelgruppe.BewegeVertikal(-80)")
        print("moebelgruppe.Drehe(30)")
        self.__alleMoebel.append(moebelgruppe)

### ---------------------------------------------------
if __name__ == '__main__':
    app = RaumplanerApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
