# sitzgruppe.py
# Fortsetzung der Entwicklung auf eine Sitzgruppe hin
# Umsetzen des Kompositummusters

from grafikfenster import *

from moebelgruppe import Moebelgruppe
from tisch import Tisch
from sessel import Sessel
from sofa import Sofa

### ---------------------------------------------------
class Sitzgruppe(Moebelgruppe):
    '''Die Klasse Sitzgruppe erzeugt automatisch die Objekte,
    ein Tischobjekt und mehrere Sesselobjekte.
    Begonnen wird mit einer leeren Sitzgruppe, der durch
    Konfigurieren die notwendigen Teile definiert werden.
    Umsetzung des Kompositummusters in Transformiere von Moebel.'''
    def __init__(self,
                 xPos=50,
                 yPos=50,
                 winkel=0,
                 farbe="",
                 sichtbar=False):
        Moebelgruppe.__init__(self, xPos, yPos, winkel, farbe, sichtbar)
        self.ErzeugeSitzgruppe()

    def ErzeugeSitzgruppe(self):
        global sitzgruppe, sofa1,sessel1, tisch
        """die Sitzgruppe wird neu erzeugt, keine Varianten möglich"""
        self.LoescheAlle()
        sofa1 = Sofa(0,100,winkel=270)
        self.FuegeHinzu( sofa1 )
        sessel1 = Sessel(150,0)
        self.FuegeHinzu( sessel1 )
        sofa2 = Sofa(100,200,breite=160,winkel=180)
        self.FuegeHinzu( sofa2 )
        sessel2 = Sessel(260,100,winkel=90)
        self.FuegeHinzu( sessel2 )
        tisch = Tisch(130,90,100,80,farbe='GRAY')
        self.FuegeHinzu( tisch )

### ---------------------------------------------------
class SitzgruppeApp(wx.App):
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        self.TestAnwendungSitzgruppe()
        #self.fenster.ZeigeFillingFrame()
        ##Zeichenflaeche.GibZeichenflaeche().SetBGImage('beispielbild.png',0.8)
        ##Zeichenflaeche.GibZeichenflaeche().SetBGColor('BLACK')
        return True

        
    def TestAnwendungSitzgruppe(self):        
        global sitzgruppe
        print('global: sitzgruppe\nSitzgruppe mit zwei Sofas und zwei Sesseln')
        try:
            sitzgruppe.LoescheAlle()
        except Exception as e:
            sitzgruppe=Sitzgruppe(sichtbar=True)

### ---------------------------------------------------
if __name__ == '__main__':
    app = SitzgruppeApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
